@@ -61,13 +61,9 @@ def process(
             phc_output_dir,
         )
 
-        extract_copy_numbers(
-            results_payload_dict, sample_name, base_xml_name, local_output_dir, log
-        )
+        extract_copy_numbers(results_payload_dict, base_xml_name, local_output_dir, log)
 
-        extract_fusion_variant(
-            results_payload_dict, sample_name, base_xml_name, local_output_dir, log
-        )
+        extract_fusion_variant(results_payload_dict, base_xml_name, local_output_dir, log)
 
         with open(
             f"{local_output_dir}/{base_xml_name}/{base_xml_name}.ga4gh.genomics.yml",
