@@ -59,7 +59,7 @@ def test_json():
     tar = f"{BASE_PATH}/resources/carisSample.tar.gz"
     process_caris(tar, local_output_dir, "carisSample")
     resulting_files = [path.name for path in Path(f"{local_output_dir}").iterdir()]
-    assert "carisSample.ga4gh.tmp" in resulting_files
+    assert "carisSample.ga4gh.genomics.yml" in resulting_files
 
 
 def test_extract_metadata():
